.. _install:
Installing tessilator software
==============================

Direct installation using pip 
-----------------------------

The easiest way to install the last released version of tessilator is to install it with pip into your Python environment::

  pip install tessilator
  
This should automatically install your dependencies, if you don't have them yet, in particular `numpy <https://numpy.org>`_ 
and `matplotlib <https://matplotlib.org>`_.

Cloning the GitHub repository
-----------------------------

Users with GitHub accounts are able to clone the repository directly. This can be done interactively using the GitHub online
interface. `The link to the GitHub repository is here. <https://github.com/alexbinks/TESSilator>`_ Alternatively the repository
can be cloned from any linux command line as follows::

  git clone https://github.com/alexbinks/TESSilator

